# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.1

import enum
import typing
import uuid as _uuid

import winrt.system
from winrt import _winrt_windows_devices_sms

__all__ = [
    "CellularClass",
    "SmsBroadcastType",
    "SmsDataFormat",
    "SmsDeviceStatus",
    "SmsEncoding",
    "SmsFilterActionType",
    "SmsGeographicalScope",
    "SmsMessageClass",
    "SmsMessageFilter",
    "SmsMessageType",
    "SmsModemErrorCode",
    "SmsEncodedLength",
    "DeleteSmsMessageOperation",
    "DeleteSmsMessagesOperation",
    "GetSmsDeviceOperation",
    "GetSmsMessageOperation",
    "GetSmsMessagesOperation",
    "SendSmsMessageOperation",
    "SmsAppMessage",
    "SmsBinaryMessage",
    "SmsBroadcastMessage",
    "SmsDevice",
    "SmsDevice2",
    "SmsDeviceMessageStore",
    "SmsFilterRule",
    "SmsFilterRules",
    "SmsMessageReceivedEventArgs",
    "SmsMessageReceivedTriggerDetails",
    "SmsMessageRegistration",
    "SmsReceivedEventDetails",
    "SmsSendMessageResult",
    "SmsStatusMessage",
    "SmsTextMessage",
    "SmsTextMessage2",
    "SmsVoicemailMessage",
    "SmsWapMessage",
    "ISmsBinaryMessage",
    "ISmsDevice",
    "ISmsMessage",
    "ISmsMessageBase",
    "ISmsTextMessage",
    "SmsDeviceStatusChangedEventHandler",
    "SmsMessageReceivedEventHandler",
]

class CellularClass(enum.IntEnum):
    NONE = 0
    GSM = 1
    CDMA = 2

class SmsBroadcastType(enum.IntEnum):
    OTHER = 0
    CMAS_PRESIDENTIAL = 1
    CMAS_EXTREME = 2
    CMAS_SEVERE = 3
    CMAS_AMBER = 4
    CMAS_TEST = 5
    E_U_ALERT1 = 6
    E_U_ALERT2 = 7
    E_U_ALERT3 = 8
    E_U_ALERT_AMBER = 9
    E_U_ALERT_INFO = 10
    ETWS_EARTHQUAKE = 11
    ETWS_TSUNAMI = 12
    ETWS_TSUNAMI_AND_EARTHQUAKE = 13
    LAT_ALERT_LOCAL = 14

class SmsDataFormat(enum.IntEnum):
    UNKNOWN = 0
    CDMA_SUBMIT = 1
    GSM_SUBMIT = 2
    CDMA_DELIVER = 3
    GSM_DELIVER = 4

class SmsDeviceStatus(enum.IntEnum):
    OFF = 0
    READY = 1
    SIM_NOT_INSERTED = 2
    BAD_SIM = 3
    DEVICE_FAILURE = 4
    SUBSCRIPTION_NOT_ACTIVATED = 5
    DEVICE_LOCKED = 6
    DEVICE_BLOCKED = 7

class SmsEncoding(enum.IntEnum):
    UNKNOWN = 0
    OPTIMAL = 1
    SEVEN_BIT_ASCII = 2
    UNICODE = 3
    GSM_SEVEN_BIT = 4
    EIGHT_BIT = 5
    LATIN = 6
    KOREAN = 7
    I_A5 = 8
    SHIFT_JIS = 9
    LATIN_HEBREW = 10

class SmsFilterActionType(enum.IntEnum):
    ACCEPT_IMMEDIATELY = 0
    DROP = 1
    PEEK = 2
    ACCEPT = 3

class SmsGeographicalScope(enum.IntEnum):
    NONE = 0
    CELL_WITH_IMMEDIATE_DISPLAY = 1
    LOCATION_AREA = 2
    PLMN = 3
    CELL = 4

class SmsMessageClass(enum.IntEnum):
    NONE = 0
    CLASS0 = 1
    CLASS1 = 2
    CLASS2 = 3
    CLASS3 = 4

class SmsMessageFilter(enum.IntEnum):
    ALL = 0
    UNREAD = 1
    READ = 2
    SENT = 3
    DRAFT = 4

class SmsMessageType(enum.IntEnum):
    BINARY = 0
    TEXT = 1
    WAP = 2
    APP = 3
    BROADCAST = 4
    VOICEMAIL = 5
    STATUS = 6

class SmsModemErrorCode(enum.IntEnum):
    OTHER = 0
    MESSAGING_NETWORK_ERROR = 1
    SMS_OPERATION_NOT_SUPPORTED_BY_DEVICE = 2
    SMS_SERVICE_NOT_SUPPORTED_BY_NETWORK = 3
    DEVICE_FAILURE = 4
    MESSAGE_NOT_ENCODED_PROPERLY = 5
    MESSAGE_TOO_LARGE = 6
    DEVICE_NOT_READY = 7
    NETWORK_NOT_READY = 8
    INVALID_SMSC_ADDRESS = 9
    NETWORK_FAILURE = 10
    FIXED_DIALING_NUMBER_RESTRICTED = 11

SmsEncodedLength = _winrt_windows_devices_sms.SmsEncodedLength
DeleteSmsMessageOperation = _winrt_windows_devices_sms.DeleteSmsMessageOperation
DeleteSmsMessagesOperation = _winrt_windows_devices_sms.DeleteSmsMessagesOperation
GetSmsDeviceOperation = _winrt_windows_devices_sms.GetSmsDeviceOperation
GetSmsMessageOperation = _winrt_windows_devices_sms.GetSmsMessageOperation
GetSmsMessagesOperation = _winrt_windows_devices_sms.GetSmsMessagesOperation
SendSmsMessageOperation = _winrt_windows_devices_sms.SendSmsMessageOperation
SmsAppMessage = _winrt_windows_devices_sms.SmsAppMessage
SmsBinaryMessage = _winrt_windows_devices_sms.SmsBinaryMessage
SmsBroadcastMessage = _winrt_windows_devices_sms.SmsBroadcastMessage
SmsDevice = _winrt_windows_devices_sms.SmsDevice
SmsDevice2 = _winrt_windows_devices_sms.SmsDevice2
SmsDeviceMessageStore = _winrt_windows_devices_sms.SmsDeviceMessageStore
SmsFilterRule = _winrt_windows_devices_sms.SmsFilterRule
SmsFilterRules = _winrt_windows_devices_sms.SmsFilterRules
SmsMessageReceivedEventArgs = _winrt_windows_devices_sms.SmsMessageReceivedEventArgs
SmsMessageReceivedTriggerDetails = _winrt_windows_devices_sms.SmsMessageReceivedTriggerDetails
SmsMessageRegistration = _winrt_windows_devices_sms.SmsMessageRegistration
SmsReceivedEventDetails = _winrt_windows_devices_sms.SmsReceivedEventDetails
SmsSendMessageResult = _winrt_windows_devices_sms.SmsSendMessageResult
SmsStatusMessage = _winrt_windows_devices_sms.SmsStatusMessage
SmsTextMessage = _winrt_windows_devices_sms.SmsTextMessage
SmsTextMessage2 = _winrt_windows_devices_sms.SmsTextMessage2
SmsVoicemailMessage = _winrt_windows_devices_sms.SmsVoicemailMessage
SmsWapMessage = _winrt_windows_devices_sms.SmsWapMessage
ISmsBinaryMessage = _winrt_windows_devices_sms.ISmsBinaryMessage
ISmsDevice = _winrt_windows_devices_sms.ISmsDevice
ISmsMessage = _winrt_windows_devices_sms.ISmsMessage
ISmsMessageBase = _winrt_windows_devices_sms.ISmsMessageBase
ISmsTextMessage = _winrt_windows_devices_sms.ISmsTextMessage
SmsDeviceStatusChangedEventHandler = typing.Callable[[typing.Optional[SmsDevice]], None]
SmsMessageReceivedEventHandler = typing.Callable[[typing.Optional[SmsDevice], typing.Optional[SmsMessageReceivedEventArgs]], None]



# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.1

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation
import winrt.windows.foundation.collections
import winrt.windows.storage.streams

from winrt.windows.devices.sms import CellularClass, SmsBroadcastType, SmsDataFormat, SmsDeviceStatus, SmsEncoding, SmsFilterActionType, SmsGeographicalScope, SmsMessageClass, SmsMessageFilter, SmsMessageType, SmsModemErrorCode
from winrt.windows.devices.sms import SmsDeviceStatusChangedEventHandler, SmsMessageReceivedEventHandler

Self = typing.TypeVar('Self')

@typing.final
class SmsEncodedLength:
    segment_count: winrt.system.UInt32
    character_count_last_segment: winrt.system.UInt32
    characters_per_segment: winrt.system.UInt32
    byte_count_last_segment: winrt.system.UInt32
    bytes_per_segment: winrt.system.UInt32
    def __init__(self, segment_count: winrt.system.UInt32, character_count_last_segment: winrt.system.UInt32, characters_per_segment: winrt.system.UInt32, byte_count_last_segment: winrt.system.UInt32, bytes_per_segment: winrt.system.UInt32) -> None: ...

@typing.final
class DeleteSmsMessageOperation(winrt.system.Object):
    def __await__(self) -> typing.Generator[typing.Any, None, None]: ...
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> DeleteSmsMessageOperation: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> None: ...
    @_property
    def error_code(self) -> winrt.windows.foundation.HResult: ...
    @_property
    def id(self) -> winrt.system.UInt32: ...
    @_property
    def status(self) -> winrt.windows.foundation.AsyncStatus: ...
    @_property
    def completed(self) -> typing.Optional[winrt.windows.foundation.AsyncActionCompletedHandler]: ...
    @completed.setter
    def completed(self, value: typing.Optional[winrt.windows.foundation.AsyncActionCompletedHandler]) -> None: ...

@typing.final
class DeleteSmsMessagesOperation(winrt.system.Object):
    def __await__(self) -> typing.Generator[typing.Any, None, None]: ...
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> DeleteSmsMessagesOperation: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> None: ...
    @_property
    def error_code(self) -> winrt.windows.foundation.HResult: ...
    @_property
    def id(self) -> winrt.system.UInt32: ...
    @_property
    def status(self) -> winrt.windows.foundation.AsyncStatus: ...
    @_property
    def completed(self) -> typing.Optional[winrt.windows.foundation.AsyncActionCompletedHandler]: ...
    @completed.setter
    def completed(self, value: typing.Optional[winrt.windows.foundation.AsyncActionCompletedHandler]) -> None: ...

@typing.final
class GetSmsDeviceOperation(winrt.system.Object):
    def __await__(self) -> typing.Generator[typing.Any, None, typing.Optional[SmsDevice]]: ...
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> GetSmsDeviceOperation: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> typing.Optional[SmsDevice]: ...
    @_property
    def error_code(self) -> winrt.windows.foundation.HResult: ...
    @_property
    def id(self) -> winrt.system.UInt32: ...
    @_property
    def status(self) -> winrt.windows.foundation.AsyncStatus: ...
    @_property
    def completed(self) -> typing.Optional[winrt.windows.foundation.AsyncOperationCompletedHandler[SmsDevice]]: ...
    @completed.setter
    def completed(self, value: typing.Optional[winrt.windows.foundation.AsyncOperationCompletedHandler[SmsDevice]]) -> None: ...

@typing.final
class GetSmsMessageOperation(winrt.system.Object):
    def __await__(self) -> typing.Generator[typing.Any, None, typing.Optional[ISmsMessage]]: ...
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> GetSmsMessageOperation: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> typing.Optional[ISmsMessage]: ...
    @_property
    def error_code(self) -> winrt.windows.foundation.HResult: ...
    @_property
    def id(self) -> winrt.system.UInt32: ...
    @_property
    def status(self) -> winrt.windows.foundation.AsyncStatus: ...
    @_property
    def completed(self) -> typing.Optional[winrt.windows.foundation.AsyncOperationCompletedHandler[ISmsMessage]]: ...
    @completed.setter
    def completed(self, value: typing.Optional[winrt.windows.foundation.AsyncOperationCompletedHandler[ISmsMessage]]) -> None: ...

@typing.final
class GetSmsMessagesOperation(winrt.system.Object):
    def __await__(self) -> typing.Generator[typing.Any, None, typing.Optional[winrt.windows.foundation.collections.IVectorView[ISmsMessage]]]: ...
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> GetSmsMessagesOperation: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> typing.Optional[winrt.windows.foundation.collections.IVectorView[ISmsMessage]]: ...
    @_property
    def error_code(self) -> winrt.windows.foundation.HResult: ...
    @_property
    def id(self) -> winrt.system.UInt32: ...
    @_property
    def status(self) -> winrt.windows.foundation.AsyncStatus: ...
    @_property
    def progress(self) -> typing.Optional[winrt.windows.foundation.AsyncOperationProgressHandler[winrt.windows.foundation.collections.IVectorView[ISmsMessage], winrt.system.Int32]]: ...
    @progress.setter
    def progress(self, value: typing.Optional[winrt.windows.foundation.AsyncOperationProgressHandler[winrt.windows.foundation.collections.IVectorView[ISmsMessage], winrt.system.Int32]]) -> None: ...
    @_property
    def completed(self) -> typing.Optional[winrt.windows.foundation.AsyncOperationWithProgressCompletedHandler[winrt.windows.foundation.collections.IVectorView[ISmsMessage], winrt.system.Int32]]: ...
    @completed.setter
    def completed(self, value: typing.Optional[winrt.windows.foundation.AsyncOperationWithProgressCompletedHandler[winrt.windows.foundation.collections.IVectorView[ISmsMessage], winrt.system.Int32]]) -> None: ...

@typing.final
class SendSmsMessageOperation(winrt.system.Object):
    def __await__(self) -> typing.Generator[typing.Any, None, None]: ...
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SendSmsMessageOperation: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> None: ...
    @_property
    def error_code(self) -> winrt.windows.foundation.HResult: ...
    @_property
    def id(self) -> winrt.system.UInt32: ...
    @_property
    def status(self) -> winrt.windows.foundation.AsyncStatus: ...
    @_property
    def completed(self) -> typing.Optional[winrt.windows.foundation.AsyncActionCompletedHandler]: ...
    @completed.setter
    def completed(self, value: typing.Optional[winrt.windows.foundation.AsyncActionCompletedHandler]) -> None: ...

@typing.final
class SmsAppMessage(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SmsAppMessage: ...
    def __new__(cls: typing.Type[SmsAppMessage]) -> SmsAppMessage:...
    @_property
    def protocol_id(self) -> winrt.system.Int32: ...
    @protocol_id.setter
    def protocol_id(self, value: winrt.system.Int32) -> None: ...
    @_property
    def port_number(self) -> winrt.system.Int32: ...
    @port_number.setter
    def port_number(self, value: winrt.system.Int32) -> None: ...
    @_property
    def is_delivery_notification_enabled(self) -> bool: ...
    @is_delivery_notification_enabled.setter
    def is_delivery_notification_enabled(self, value: bool) -> None: ...
    @_property
    def retry_attempt_count(self) -> winrt.system.Int32: ...
    @retry_attempt_count.setter
    def retry_attempt_count(self, value: winrt.system.Int32) -> None: ...
    @_property
    def encoding(self) -> SmsEncoding: ...
    @encoding.setter
    def encoding(self, value: SmsEncoding) -> None: ...
    @_property
    def body(self) -> str: ...
    @body.setter
    def body(self, value: str) -> None: ...
    @_property
    def callback_number(self) -> str: ...
    @callback_number.setter
    def callback_number(self, value: str) -> None: ...
    @_property
    def binary_body(self) -> typing.Optional[winrt.windows.storage.streams.IBuffer]: ...
    @binary_body.setter
    def binary_body(self, value: typing.Optional[winrt.windows.storage.streams.IBuffer]) -> None: ...
    @_property
    def to(self) -> str: ...
    @to.setter
    def to(self, value: str) -> None: ...
    @_property
    def teleservice_id(self) -> winrt.system.Int32: ...
    @teleservice_id.setter
    def teleservice_id(self, value: winrt.system.Int32) -> None: ...
    @_property
    def from_(self) -> str: ...
    @_property
    def timestamp(self) -> datetime.datetime: ...
    @_property
    def cellular_class(self) -> CellularClass: ...
    @_property
    def device_id(self) -> str: ...
    @_property
    def message_class(self) -> SmsMessageClass: ...
    @_property
    def message_type(self) -> SmsMessageType: ...
    @_property
    def sim_icc_id(self) -> str: ...

@typing.final
class SmsBinaryMessage(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SmsBinaryMessage: ...
    def __new__(cls: typing.Type[SmsBinaryMessage]) -> SmsBinaryMessage:...
    def get_data(self) -> winrt.system.UInt8: ...
    def set_data(self, value: winrt.system.Array[winrt.system.UInt8], /) -> None: ...
    @_property
    def format(self) -> SmsDataFormat: ...
    @format.setter
    def format(self, value: SmsDataFormat) -> None: ...
    @_property
    def id(self) -> winrt.system.UInt32: ...
    @_property
    def message_class(self) -> SmsMessageClass: ...

@typing.final
class SmsBroadcastMessage(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SmsBroadcastMessage: ...
    @_property
    def body(self) -> str: ...
    @_property
    def broadcast_type(self) -> SmsBroadcastType: ...
    @_property
    def channel(self) -> winrt.system.Int32: ...
    @_property
    def geographical_scope(self) -> SmsGeographicalScope: ...
    @_property
    def is_emergency_alert(self) -> bool: ...
    @_property
    def is_user_popup_requested(self) -> bool: ...
    @_property
    def message_code(self) -> winrt.system.Int32: ...
    @_property
    def timestamp(self) -> datetime.datetime: ...
    @_property
    def to(self) -> str: ...
    @_property
    def update_number(self) -> winrt.system.Int32: ...
    @_property
    def cellular_class(self) -> CellularClass: ...
    @_property
    def device_id(self) -> str: ...
    @_property
    def message_class(self) -> SmsMessageClass: ...
    @_property
    def message_type(self) -> SmsMessageType: ...
    @_property
    def sim_icc_id(self) -> str: ...

@typing.final
class SmsDevice_Static(type):
    def from_id_async(cls, device_id: str, /) -> winrt.windows.foundation.IAsyncOperation[SmsDevice]: ...
    def from_network_account_id_async(cls, network_account_id: str, /) -> winrt.windows.foundation.IAsyncOperation[SmsDevice]: ...
    def get_default_async(cls) -> winrt.windows.foundation.IAsyncOperation[SmsDevice]: ...
    def get_device_selector(cls) -> str: ...

@typing.final
class SmsDevice(winrt.system.Object, metaclass=SmsDevice_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SmsDevice: ...
    def calculate_length(self, message: typing.Optional[SmsTextMessage], /) -> SmsEncodedLength: ...
    def send_message_async(self, message: typing.Optional[ISmsMessage], /) -> SendSmsMessageOperation: ...
    def add_sms_device_status_changed(self, event_handler: typing.Optional[SmsDeviceStatusChangedEventHandler], /) -> winrt.windows.foundation.EventRegistrationToken: ...
    def remove_sms_device_status_changed(self, event_cookie: winrt.windows.foundation.EventRegistrationToken, /) -> None: ...
    def add_sms_message_received(self, event_handler: typing.Optional[SmsMessageReceivedEventHandler], /) -> winrt.windows.foundation.EventRegistrationToken: ...
    def remove_sms_message_received(self, event_cookie: winrt.windows.foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def account_phone_number(self) -> str: ...
    @_property
    def cellular_class(self) -> CellularClass: ...
    @_property
    def device_status(self) -> SmsDeviceStatus: ...
    @_property
    def message_store(self) -> typing.Optional[SmsDeviceMessageStore]: ...

@typing.final
class SmsDevice2_Static(type):
    def from_id(cls, device_id: str, /) -> typing.Optional[SmsDevice2]: ...
    def from_parent_id(cls, parent_device_id: str, /) -> typing.Optional[SmsDevice2]: ...
    def get_default(cls) -> typing.Optional[SmsDevice2]: ...
    def get_device_selector(cls) -> str: ...

@typing.final
class SmsDevice2(winrt.system.Object, metaclass=SmsDevice2_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SmsDevice2: ...
    def calculate_length(self, message: typing.Optional[ISmsMessageBase], /) -> SmsEncodedLength: ...
    def send_message_and_get_result_async(self, message: typing.Optional[ISmsMessageBase], /) -> winrt.windows.foundation.IAsyncOperation[SmsSendMessageResult]: ...
    def add_device_status_changed(self, event_handler: winrt.windows.foundation.TypedEventHandler[SmsDevice2, winrt.system.Object], /) -> winrt.windows.foundation.EventRegistrationToken: ...
    def remove_device_status_changed(self, event_cookie: winrt.windows.foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def smsc_address(self) -> str: ...
    @smsc_address.setter
    def smsc_address(self, value: str) -> None: ...
    @_property
    def account_phone_number(self) -> str: ...
    @_property
    def cellular_class(self) -> CellularClass: ...
    @_property
    def device_id(self) -> str: ...
    @_property
    def device_status(self) -> SmsDeviceStatus: ...
    @_property
    def parent_device_id(self) -> str: ...

@typing.final
class SmsDeviceMessageStore(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SmsDeviceMessageStore: ...
    def delete_message_async(self, message_id: winrt.system.UInt32, /) -> winrt.windows.foundation.IAsyncAction: ...
    def delete_messages_async(self, message_filter: SmsMessageFilter, /) -> winrt.windows.foundation.IAsyncAction: ...
    def get_message_async(self, message_id: winrt.system.UInt32, /) -> winrt.windows.foundation.IAsyncOperation[ISmsMessage]: ...
    def get_messages_async(self, message_filter: SmsMessageFilter, /) -> winrt.windows.foundation.IAsyncOperationWithProgress[winrt.windows.foundation.collections.IVectorView[ISmsMessage], winrt.system.Int32]: ...
    @_property
    def max_messages(self) -> winrt.system.UInt32: ...

@typing.final
class SmsFilterRule(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SmsFilterRule: ...
    def __new__(cls: typing.Type[SmsFilterRule], message_type: SmsMessageType) -> SmsFilterRule:...
    @_property
    def cellular_class(self) -> CellularClass: ...
    @cellular_class.setter
    def cellular_class(self, value: CellularClass) -> None: ...
    @_property
    def broadcast_channels(self) -> typing.Optional[winrt.windows.foundation.collections.IVector[winrt.system.Int32]]: ...
    @_property
    def broadcast_types(self) -> typing.Optional[winrt.windows.foundation.collections.IVector[SmsBroadcastType]]: ...
    @_property
    def device_ids(self) -> typing.Optional[winrt.windows.foundation.collections.IVector[str]]: ...
    @_property
    def imsi_prefixes(self) -> typing.Optional[winrt.windows.foundation.collections.IVector[str]]: ...
    @_property
    def message_type(self) -> SmsMessageType: ...
    @_property
    def port_numbers(self) -> typing.Optional[winrt.windows.foundation.collections.IVector[winrt.system.Int32]]: ...
    @_property
    def protocol_ids(self) -> typing.Optional[winrt.windows.foundation.collections.IVector[winrt.system.Int32]]: ...
    @_property
    def sender_numbers(self) -> typing.Optional[winrt.windows.foundation.collections.IVector[str]]: ...
    @_property
    def teleservice_ids(self) -> typing.Optional[winrt.windows.foundation.collections.IVector[winrt.system.Int32]]: ...
    @_property
    def text_message_prefixes(self) -> typing.Optional[winrt.windows.foundation.collections.IVector[str]]: ...
    @_property
    def wap_application_ids(self) -> typing.Optional[winrt.windows.foundation.collections.IVector[str]]: ...
    @_property
    def wap_content_types(self) -> typing.Optional[winrt.windows.foundation.collections.IVector[str]]: ...

@typing.final
class SmsFilterRules(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SmsFilterRules: ...
    def __new__(cls: typing.Type[SmsFilterRules], action_type: SmsFilterActionType) -> SmsFilterRules:...
    @_property
    def action_type(self) -> SmsFilterActionType: ...
    @_property
    def rules(self) -> typing.Optional[winrt.windows.foundation.collections.IVector[SmsFilterRule]]: ...

@typing.final
class SmsMessageReceivedEventArgs(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SmsMessageReceivedEventArgs: ...
    @_property
    def binary_message(self) -> typing.Optional[SmsBinaryMessage]: ...
    @_property
    def text_message(self) -> typing.Optional[SmsTextMessage]: ...

@typing.final
class SmsMessageReceivedTriggerDetails(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SmsMessageReceivedTriggerDetails: ...
    def accept(self) -> None: ...
    def drop(self) -> None: ...
    @_property
    def app_message(self) -> typing.Optional[SmsAppMessage]: ...
    @_property
    def broadcast_message(self) -> typing.Optional[SmsBroadcastMessage]: ...
    @_property
    def message_type(self) -> SmsMessageType: ...
    @_property
    def status_message(self) -> typing.Optional[SmsStatusMessage]: ...
    @_property
    def text_message(self) -> typing.Optional[SmsTextMessage2]: ...
    @_property
    def voicemail_message(self) -> typing.Optional[SmsVoicemailMessage]: ...
    @_property
    def wap_message(self) -> typing.Optional[SmsWapMessage]: ...

@typing.final
class SmsMessageRegistration_Static(type):
    def register(cls, id: str, filter_rules: typing.Optional[SmsFilterRules], /) -> typing.Optional[SmsMessageRegistration]: ...
    @_property
    def all_registrations(cls) -> typing.Optional[winrt.windows.foundation.collections.IVectorView[SmsMessageRegistration]]: ...

@typing.final
class SmsMessageRegistration(winrt.system.Object, metaclass=SmsMessageRegistration_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SmsMessageRegistration: ...
    def unregister(self) -> None: ...
    def add_message_received(self, event_handler: winrt.windows.foundation.TypedEventHandler[SmsMessageRegistration, SmsMessageReceivedTriggerDetails], /) -> winrt.windows.foundation.EventRegistrationToken: ...
    def remove_message_received(self, event_cookie: winrt.windows.foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def id(self) -> str: ...

@typing.final
class SmsReceivedEventDetails(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SmsReceivedEventDetails: ...
    @_property
    def device_id(self) -> str: ...
    @_property
    def message_index(self) -> winrt.system.UInt32: ...
    @_property
    def binary_message(self) -> typing.Optional[SmsBinaryMessage]: ...
    @_property
    def message_class(self) -> SmsMessageClass: ...

@typing.final
class SmsSendMessageResult(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SmsSendMessageResult: ...
    @_property
    def cellular_class(self) -> CellularClass: ...
    @_property
    def is_error_transient(self) -> bool: ...
    @_property
    def is_successful(self) -> bool: ...
    @_property
    def message_reference_numbers(self) -> typing.Optional[winrt.windows.foundation.collections.IVectorView[winrt.system.Int32]]: ...
    @_property
    def modem_error_code(self) -> SmsModemErrorCode: ...
    @_property
    def network_cause_code(self) -> winrt.system.Int32: ...
    @_property
    def transport_failure_cause(self) -> winrt.system.Int32: ...

@typing.final
class SmsStatusMessage(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SmsStatusMessage: ...
    @_property
    def cellular_class(self) -> CellularClass: ...
    @_property
    def device_id(self) -> str: ...
    @_property
    def message_class(self) -> SmsMessageClass: ...
    @_property
    def message_type(self) -> SmsMessageType: ...
    @_property
    def sim_icc_id(self) -> str: ...
    @_property
    def status(self) -> winrt.system.Int32: ...
    @_property
    def body(self) -> str: ...
    @_property
    def discharge_time(self) -> datetime.datetime: ...
    @_property
    def from_(self) -> str: ...
    @_property
    def message_reference_number(self) -> winrt.system.Int32: ...
    @_property
    def service_center_timestamp(self) -> datetime.datetime: ...
    @_property
    def to(self) -> str: ...

@typing.final
class SmsTextMessage_Static(type):
    def from_binary_data(cls, format: SmsDataFormat, value: winrt.system.Array[winrt.system.UInt8], /) -> typing.Optional[SmsTextMessage]: ...
    def from_binary_message(cls, binary_message: typing.Optional[SmsBinaryMessage], /) -> typing.Optional[SmsTextMessage]: ...

@typing.final
class SmsTextMessage(winrt.system.Object, metaclass=SmsTextMessage_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SmsTextMessage: ...
    def __new__(cls: typing.Type[SmsTextMessage]) -> SmsTextMessage:...
    def to_binary_messages(self, format: SmsDataFormat, /) -> typing.Optional[winrt.windows.foundation.collections.IVectorView[ISmsBinaryMessage]]: ...
    @_property
    def id(self) -> winrt.system.UInt32: ...
    @_property
    def message_class(self) -> SmsMessageClass: ...
    @_property
    def to(self) -> str: ...
    @to.setter
    def to(self, value: str) -> None: ...
    @_property
    def from_(self) -> str: ...
    @from_.setter
    def from_(self, value: str) -> None: ...
    @_property
    def encoding(self) -> SmsEncoding: ...
    @encoding.setter
    def encoding(self, value: SmsEncoding) -> None: ...
    @_property
    def body(self) -> str: ...
    @body.setter
    def body(self, value: str) -> None: ...
    @_property
    def part_count(self) -> winrt.system.UInt32: ...
    @_property
    def part_number(self) -> winrt.system.UInt32: ...
    @_property
    def part_reference_id(self) -> winrt.system.UInt32: ...
    @_property
    def timestamp(self) -> datetime.datetime: ...

@typing.final
class SmsTextMessage2(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SmsTextMessage2: ...
    def __new__(cls: typing.Type[SmsTextMessage2]) -> SmsTextMessage2:...
    @_property
    def message_type(self) -> SmsMessageType: ...
    @_property
    def device_id(self) -> str: ...
    @_property
    def cellular_class(self) -> CellularClass: ...
    @_property
    def message_class(self) -> SmsMessageClass: ...
    @_property
    def sim_icc_id(self) -> str: ...
    @_property
    def retry_attempt_count(self) -> winrt.system.Int32: ...
    @retry_attempt_count.setter
    def retry_attempt_count(self, value: winrt.system.Int32) -> None: ...
    @_property
    def to(self) -> str: ...
    @to.setter
    def to(self, value: str) -> None: ...
    @_property
    def is_delivery_notification_enabled(self) -> bool: ...
    @is_delivery_notification_enabled.setter
    def is_delivery_notification_enabled(self, value: bool) -> None: ...
    @_property
    def encoding(self) -> SmsEncoding: ...
    @encoding.setter
    def encoding(self, value: SmsEncoding) -> None: ...
    @_property
    def callback_number(self) -> str: ...
    @callback_number.setter
    def callback_number(self, value: str) -> None: ...
    @_property
    def body(self) -> str: ...
    @body.setter
    def body(self, value: str) -> None: ...
    @_property
    def protocol_id(self) -> winrt.system.Int32: ...
    @_property
    def from_(self) -> str: ...
    @_property
    def timestamp(self) -> datetime.datetime: ...
    @_property
    def teleservice_id(self) -> winrt.system.Int32: ...

@typing.final
class SmsVoicemailMessage(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SmsVoicemailMessage: ...
    @_property
    def cellular_class(self) -> CellularClass: ...
    @_property
    def device_id(self) -> str: ...
    @_property
    def message_class(self) -> SmsMessageClass: ...
    @_property
    def message_type(self) -> SmsMessageType: ...
    @_property
    def sim_icc_id(self) -> str: ...
    @_property
    def body(self) -> str: ...
    @_property
    def message_count(self) -> typing.Optional[typing.Optional[winrt.system.Int32]]: ...
    @_property
    def timestamp(self) -> datetime.datetime: ...
    @_property
    def to(self) -> str: ...

@typing.final
class SmsWapMessage(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SmsWapMessage: ...
    @_property
    def cellular_class(self) -> CellularClass: ...
    @_property
    def device_id(self) -> str: ...
    @_property
    def message_class(self) -> SmsMessageClass: ...
    @_property
    def message_type(self) -> SmsMessageType: ...
    @_property
    def sim_icc_id(self) -> str: ...
    @_property
    def timestamp(self) -> datetime.datetime: ...
    @_property
    def application_id(self) -> str: ...
    @_property
    def binary_body(self) -> typing.Optional[winrt.windows.storage.streams.IBuffer]: ...
    @_property
    def content_type(self) -> str: ...
    @_property
    def from_(self) -> str: ...
    @_property
    def headers(self) -> typing.Optional[winrt.windows.foundation.collections.IMap[str, str]]: ...
    @_property
    def to(self) -> str: ...

@typing.final
class ISmsBinaryMessage(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ISmsBinaryMessage: ...
    def get_data(self) -> winrt.system.UInt8: ...
    def set_data(self, value: winrt.system.Array[winrt.system.UInt8], /) -> None: ...
    @_property
    def format(self) -> SmsDataFormat: ...
    @format.setter
    def format(self, value: SmsDataFormat) -> None: ...
    @_property
    def id(self) -> winrt.system.UInt32: ...
    @_property
    def message_class(self) -> SmsMessageClass: ...

@typing.final
class ISmsDevice(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ISmsDevice: ...
    def calculate_length(self, message: typing.Optional[SmsTextMessage], /) -> SmsEncodedLength: ...
    def send_message_async(self, message: typing.Optional[ISmsMessage], /) -> SendSmsMessageOperation: ...
    def add_sms_device_status_changed(self, event_handler: typing.Optional[SmsDeviceStatusChangedEventHandler], /) -> winrt.windows.foundation.EventRegistrationToken: ...
    def remove_sms_device_status_changed(self, event_cookie: winrt.windows.foundation.EventRegistrationToken, /) -> None: ...
    def add_sms_message_received(self, event_handler: typing.Optional[SmsMessageReceivedEventHandler], /) -> winrt.windows.foundation.EventRegistrationToken: ...
    def remove_sms_message_received(self, event_cookie: winrt.windows.foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def account_phone_number(self) -> str: ...
    @_property
    def cellular_class(self) -> CellularClass: ...
    @_property
    def device_status(self) -> SmsDeviceStatus: ...
    @_property
    def message_store(self) -> typing.Optional[SmsDeviceMessageStore]: ...

@typing.final
class ISmsMessage(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ISmsMessage: ...
    @_property
    def id(self) -> winrt.system.UInt32: ...
    @_property
    def message_class(self) -> SmsMessageClass: ...

@typing.final
class ISmsMessageBase(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ISmsMessageBase: ...
    @_property
    def cellular_class(self) -> CellularClass: ...
    @_property
    def device_id(self) -> str: ...
    @_property
    def message_class(self) -> SmsMessageClass: ...
    @_property
    def message_type(self) -> SmsMessageType: ...
    @_property
    def sim_icc_id(self) -> str: ...

@typing.final
class ISmsTextMessage(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ISmsTextMessage: ...
    def to_binary_messages(self, format: SmsDataFormat, /) -> typing.Optional[winrt.windows.foundation.collections.IVectorView[ISmsBinaryMessage]]: ...
    @_property
    def body(self) -> str: ...
    @body.setter
    def body(self, value: str) -> None: ...
    @_property
    def encoding(self) -> SmsEncoding: ...
    @encoding.setter
    def encoding(self, value: SmsEncoding) -> None: ...
    @_property
    def from_(self) -> str: ...
    @from_.setter
    def from_(self, value: str) -> None: ...
    @_property
    def part_count(self) -> winrt.system.UInt32: ...
    @_property
    def part_number(self) -> winrt.system.UInt32: ...
    @_property
    def part_reference_id(self) -> winrt.system.UInt32: ...
    @_property
    def timestamp(self) -> datetime.datetime: ...
    @_property
    def to(self) -> str: ...
    @to.setter
    def to(self, value: str) -> None: ...
    @_property
    def id(self) -> winrt.system.UInt32: ...
    @_property
    def message_class(self) -> SmsMessageClass: ...

